%% Load required data for analysis.
%----Author: Guru Raghav Raman----
clear
close all
clc

%% COVID-19 case numbers
cases_data_table=readtable('Covid_cases_Singapore.xlsx','ReadVariableNames',true); %Singapore COVID-19 case data from 23 Jan-31 May 2020 (130 days).
case_data=table2array(cases_data_table(:,3:4)); %New cases, new recovered cases daily
case_data=[zeros(83,2);case_data]; %Add in zeros for the days from 1 Nov 2019 to 22 Jan 2020 (83 days).

%% Electricity demand data
%Load demand data for 10246 households (in half-hourly resolution).
% From 1 Nov 2019-31 May 2020 (213 days)
% Dimensions: 48 intervals x N days in month x 10246 consumers
% Unit is kWh per half-hour interval. Need to multiply by 2 to get in kW
% values.
load('nov2019_data_new')
load('dec2019_data_new')
load('jan2020_data_new')
load('feb2020_data_new')
load('mar2020_data_new')
load('apr2020_data_new')
load('may2020_data_new')

demand_data=cat(2,nov2019_data_new,dec2019_data_new,jan2020_data_new,feb2020_data_new,mar2020_data_new,apr2020_data_new,may2020_data_new);

% Aggregate and peak aggregate demand for the period 23 Jan 2020-31 Mar 2020.
total_demand=2*sum(demand_data,3); %Calculate total demand of all 10246 consumers. %Multiplication by 2 to convert kWh per half-hour interval to kW values
peak_total_demand=max(total_demand); %Calculate peak aggregate demand for each day.

% Calculate the average demand of a household
avg_aggregate_demand=2*mean(mean(demand_data,3)); %Multiplication by 2 to convert kWh per half-hour interval to kW values

%% Classification of consumers by dwelling type
%Classification categories:
%1: 1-Room / 2-Room HDB
%2: 3-Room HDB
%3: 4-Room HDB
%4: 5-Room and Executive HDB
%5: Private apartment and condominium
%6: Landed property
load('class_final')

%% Weather data
% Load weather data from 1 Nov 2019-24 Sept 2020. 
% (329 days; 329*48=15792 rows)
load('weather_data_reduced');
weather_1=weather_data_reduced(:,1); %First component
weather_2=weather_data_reduced(:,2); %Second component

weather_1=reshape(weather_1,48,329);
weather_2=reshape(weather_2,48,329);

%% Calendar data
t1=datetime(2019,11,1,0,0,0);
t2=datetime(2020,05,31,0,0,0);
t=t1:t2;