%% Script for preprocessing weather data.
%%----Author: Guru Raghav Raman----

%% Load weather data from 1 Nov 2019 to 24 Sept 2020 (329 days; 329*24=7896 rows). 
weather_data_ds=datastore('Singapore_weather_data.xlsx');
weather_data=readall(weather_data_ds);
weather_data(1:9,:)=[]; %Remove headers from data
weather_data.Properties.VariableNames={'DateTime','Temp','RH','TCC','SR','WS','WD'};

%Convert 1 hour resolution into 30 mins resolution by averaging between
%each hour.
weather_data_original=table2array(weather_data(:,[2,3,4,5,6]));
weather_data_interpolated=zeros(329*48,5); %Initialization.

weather_data_interpolated(1,:)=weather_data_original(1,:);

for i=2:(329*48)
    if mod(i,2)==0
        weather_data_interpolated(i,:)=weather_data_original(i/2,:);
    else
        weather_data_interpolated(i,:)=0.5*(weather_data_original((i-1)/2,:)+weather_data_original((i+1)/2,:));
    end   
end

save('weather_data_original','weather_data_original');
save('weather_data_interpolated','weather_data_interpolated');

%% Perform principal components analysis
[coeff,score,latent,tsquared,explained,mu] = pca(weather_data_interpolated);

%% Store the first two principal components which explain more than 99.9% of the variance in these 5 weather variables.
weather_data_reduced=score(:,[1 2]);
save('weather_data_reduced','weather_data_reduced');